@@ -116,20 +116,12 @@ TrueGallery = function(element, options){
         tg.setupTimer();
         
         //needs time to render for some reason !!!! NEED TO FIGURE OUT WHY!
-        setTimeout('document.trueGallery.selectFirstImage();', 1500);
-        //tg.selectFirstImage();
+        //setTimeout('document.trueGallery.selectFirstImage();', 1500);
+        tg.selectFirstImage();
     };
     
     tg.selectFirstImage = function(){
         var selectedDiv = jq(tg.selectors.firstImageContainer).addClass('selected');
-        
-        var img = selectedDiv.find('img');
-        var galleryview = jq(tg.selectors.galleryViewSelector);
-            
-        //this is the css property
-        galleryview.width(img.width());
-        galleryview.height(img.height());
-        tg.moveMediaGuide();
 
         tg.setInfo();
     }
@@ -275,12 +267,6 @@ TrueGallery = function(element, options){
         tg.triggerLoadMoreImages();
     };
 
-    tg.moveMediaGuide = function(){
-        var image = jq(tg.selectors.selectedImageSelector);
-        var media_guide = jq(tg.selectors.mediaGuideSelector);
-        media_guide.css('left', (image.width()/2) - (media_guide.width()/2));
-    }
-
     /*
      * toggleImage
      * switch bewtween two images
@@ -294,23 +280,12 @@ TrueGallery = function(element, options){
         if(newImage[0] != currentImage[0] && !tg.toggling){
             tg.toggling = true;
             tg.hide(currentImage.find('img'), function(){
-                currentImage.removeClass('selected');
-                
-                var img = newImage.find('img');
-                var galleryview = jq(tg.selectors.galleryViewSelector);
-                tg.previousGalleryBackgroundColor = galleryview.css('backgroundColor');
-                galleryview.css('backgroundColor', galleryview.parent().css('backgroundColor'));
-                    
-                //this is the css property
-                galleryview.width(img.width());
-                galleryview.height(img.height());                    
+                currentImage.removeClass('selected');                 
                 
                 tg.show(newImage.find('img'), function(){
                     tg.setNewCarouselPosition(tg.getCarouselPos(newImage));
-                    jq(tg.selectors.galleryViewSelector).attr('backgroundColor', tg.previousGalleryBackgroundColor);
                     newImage.addClass('selected');
                     tg.setInfo();
-                    tg.moveMediaGuide();
                     tg.toggling = false;
                 });
             });
@@ -371,6 +346,7 @@ TrueGallery = function(element, options){
             tg.add(image);
         });
         tg.jcar.size(this.jcar.size() + images.length);
+        tg.setInfo();
     };
     
     tg.initialize(element, options);
