@@ -25,8 +25,9 @@ class GalleryView(BrowserView):
         
     @memoize
     def firstpage(self):
-        #temp hack since for IE6, my custom kss action does not work...
-        if self.request['HTTP_USER_AGENT'].find('MSIE 6') > -1:
+
+        #temp hack since for IE6 and opera, my custom kss action does not work...
+        if self.request['HTTP_USER_AGENT'].find('MSIE 6') > -1 or self.request['HTTP_USER_AGENT'].find('Opera') > -1:
             return self.images()
         else:
             return self.context.getPage(0)
