@@ -65,7 +65,7 @@ schema = Schema((
     StringField(
         name="flickrUsername",
         widget=StringField._properties['widget'](
-            label="The username of your flickr account"
+            label="The username/id of your flickr account"
         ),
         schemata=GALLERY_TYPE,
         validators=(ValidateFlickrUsername(),)
@@ -74,7 +74,7 @@ schema = Schema((
         name="flickrSet",
         widget=StringField._properties['widget'](
             label="Set",
-            description="Name of your flickr set."
+            description="Name/id of your flickr set."
         ),
         schemata=GALLERY_TYPE,
         validators=(ValidateFlickrSet(),)
@@ -164,9 +164,17 @@ class FlickrGallery:
         
     def getFlickrUserid(self, username):
         flickr = flickrapi.FlickrAPI(API_KEY)
-        username = flickr.people_findByUsername(username=username)
         
-        return username.user[0]['nsid']
+        id = None
+        try:
+            id = flickr.people_findByUsername(username=username).user[0]['nsid']
+        except:
+            try:
+                id = flickr.people_getInfo(user_id=username).person[0]['nsid']
+            except:
+                pass
+        
+        return id
         
     def getCount(self):
         flickr = flickrapi.FlickrAPI(API_KEY)
@@ -183,7 +191,7 @@ class FlickrGallery:
         sets = flickr.photosets_getList(user_id=userid)
         
         for photoset in sets.photosets[0].photoset:
-            if photoset.title[0].text == theset:
+            if photoset.title[0].text == theset or photoset['id'] == theset:
                 return photoset['id']
                 
         return None
